[![Circle CI](https://circleci.com/gh/NSLS-II/hklpy.svg?style=svg)](https://circleci.com/gh/NSLS-II/hklpy)

[![Code Health](https://landscape.io/github/NSLS-II/hklpy/master/landscape.svg?style=flat)](https://landscape.io/github/NSLS-II/hklpy/master)

hklpy
=====

Based on the [hkl](https://github.com/picca/hkl) library, with slightly cleaner abstractions
when compared to the auto-generated gobject-introspection classes.

Integrates with ophyd pseudopositioners.

[Documentation](http://nsls-ii.github.io/) about the bluesky framework.
No documentation for *hklpy* exists at this time.

## Conda Recipes

Install the most recent tagged build: `conda install hklpy -c lightsource2-tag`

Install the most recent tagged build: `conda install hklpy -c lightsource2-dev`

Find the tagged recipe [here](https://github.com/NSLS-II/lightsource2-recipes/tree/master/recipes-tag/hklpy) and the dev recipe [here](https://github.com/NSLS-II/lightsource2-recipes/tree/master/recipes-dev/hklpy)
